@@ -1,11 +1,8 @@
-for (container in c("Queue", "QueueL")) {
+context("queue")
 
-context(container)
-
-Container <- eval(as.name(container))
 
 test_that("push, peek and pop", {
-    q <- Container()
+    q <- queue()
     q$push(1)$push(2)
     expect_equal(q$size(), 2)
     expect_equal(q$peek(), 1)
@@ -23,7 +20,7 @@ test_that("push, peek and pop", {
 })
 
 test_that("push, peek and pop with items", {
-    q <- Container(list(2, 3))
+    q <- queue(list(2, 3))
     expect_equal(q$size(), 2)
     expect_equal(q$peek(), 2)
     expect_equal(q$pop(), 2)
@@ -35,17 +32,15 @@ test_that("push, peek and pop with items", {
 })
 
 test_that("clear", {
-    q <- Container()
+    q <- queue()
     q$push("a")$push("b")$push("c")
     q$clear()
     expect_equal(q$size(), 0)
 })
 
 test_that("push NULL", {
-    q <- Container()
+    q <- queue()
     q$push(NULL)$push(NULL)
     expect_null(q$pop())
     expect_equal(q$size(), 1)
 })
-
-}
